@@ -11,10 +11,6 @@ use {
 
 fn print_analysis(path: &Path, args: &args::Args) -> Result<()> {
     let mut log_base = time!("LogBase::new", LogBase::new(path, args))?;
-    if log_base.lines.is_empty() {
-        eprintln!("no hit in logs");
-        return Ok(());
-    }
     let printer = md::Printer::new(args, &log_base);
     let base = &mut log_base;
     let trend_computer = time!("Trend computer initialization", TrendComputer::new(base, args))?;
